@@ -41,3 +41,11 @@ class NoSuchImage(DockerException):
 
 class NoSuchService(DockerException):
     pass
+
+
+class NotASwarmManager(DockerException):
+    pass
+
+
+class NoSuchVolume(DockerException):
+    pass
